@@ -2,7 +2,7 @@
 """
 Group modules and switch between them.
 
-In `i3status.conf` groups can be configured. The active one of these groups is
+Groups can be configured in your config. The active one of these groups is
 shown in the i3bar.  The active group can be changed by a user click.  If the
 click is not used by the group module then it will be passed down to the
 displayed module.
@@ -60,10 +60,7 @@ group {
 
 # Create a disks group that will show space on '/' and '/home'
 # Change between disk modules every 30 seconds
-...
 order += "group disks"
-...
-
 group disks {
     cycle = 30
     format = "Disks: {output} {button}"
@@ -72,7 +69,6 @@ group disks {
     disk "/" {
         format = "/ %avail"
     }
-
     disk "/home" {
         format = "/home %avail"
     }
@@ -95,6 +91,7 @@ from time import time
 
 # maximum wait for initial content at startup
 MAX_NO_CONTENT_WAIT = 5
+STRING_ERROR = "missing modules"
 
 
 class Py3status:
@@ -119,17 +116,16 @@ class Py3status:
         container = True
 
     def post_config_hook(self):
-        # if no items don't cycle
         if not self.items:
-            self.cycle = 0
+            raise Exception(STRING_ERROR)
 
-        self._first_run = True
         self.active = 0
+        self.cycle_time = time() + self.cycle
+        self.cycle_timeout = self.cycle
         self.last_active = 0
         self.urgent = False
-        self._cycle_time = time() + self.cycle
+        self.urgent_history = {}
 
-        self.open = bool(self.open)
         # set default format etc based on click_mode
         if self.format is None:
             if self.click_mode == "button":
@@ -144,8 +140,8 @@ class Py3status:
 
     def _content_function(self):
         """
-        This returns a set containing the actively shown module.  This is so we
-        only get update events triggered for these modules.
+        This returns a set containing the actively shown module.
+        This is so we only get update events triggered for these modules.
         """
         # ensure that active is valid
         self.active = self.active % len(self.items)
@@ -154,7 +150,8 @@ class Py3status:
 
     def _urgent_function(self, module_list):
         """
-        A contained module has become urgent.  We want to display it to the user
+        A contained module has become urgent.
+        We want to display it to the user.
         """
         for module in module_list:
             if module in self.items:
@@ -190,11 +187,6 @@ class Py3status:
                 current[-1]["full_text"] += padding
         return current
 
-    def _get_current_module_name(self):
-        if not self.items:
-            return
-        return self.items[self.active]
-
     def _change_active(self, delta):
         # we want to ignore any empty outputs
         # to prevent endless cycling we limit ourselves to only going through
@@ -205,87 +197,88 @@ class Py3status:
         self.last_active = self.active
 
     def group(self):
-        """
-        Display a output of current module
-        """
+        update_time = None
+        self.cycle = 0
 
-        # hide if no contents
-        if not self.items:
-            return {"cached_until": self.py3.CACHE_FOREVER, "full_text": ""}
-
-        if self.open:
-            urgent = False
-            if self.cycle and time() >= self._cycle_time:
-                self._change_active(1)
-                self._cycle_time = time() + self.cycle
-            update_time = self.cycle or None
-            current_output = self._get_output()
-            # if the output is empty try and find some output
-            if not current_output:
-                if self._first_run:
-                    self._first_run = False
-                    return {
-                        "cached_until": self.py3.time_in(MAX_NO_CONTENT_WAIT),
-                        "full_text": "",
-                    }
-
-                self._change_active(1)
-                current_output = self._get_output()
-                # there is no output for any module retry later
-                self._first_run = False
+        # get an output. again if empty (twice).
+        for x in range(3):
+            output = self._get_output()
+            if output:
+                break
+            self._change_active(1)
         else:
-            urgent = self.urgent
-            current_output = []
-            update_time = None
+            update_time = MAX_NO_CONTENT_WAIT
 
-        if self.open:
-            format_control = self.format_button_open
-            format = self.format
-        else:
-            format_control = self.format_button_closed
-            format = self.format_closed
+        # check for urgents
+        urgent = output and output[0].get("urgent")
+        self.urgent_history[self.active] = urgent
+        mod_urgent = any(self.urgent_history.values())
 
-        button = {"full_text": format_control, "index": "button"}
-        composites = {
-            "output": self.py3.composite_create(current_output),
-            "button": self.py3.composite_create(button),
-        }
-        output = self.py3.safe_format(format, composites)
+        # keep cycling if no urgent
+        if not urgent:
+            self.cycle = self.cycle_timeout
+            if time() >= self.cycle_time:
+                self._change_active(1)
+                self.cycle_time = time() + self.cycle
 
+        # time
+        update_time = update_time or self.cycle or None
         if update_time is not None:
-            cached_until = self.py3.time_in(update_time)
+            cached_until = self.py3.time_in(self.cycle)
         else:
             cached_until = self.py3.CACHE_FOREVER
 
-        response = {"cached_until": cached_until, "full_text": output}
+        if self.open:
+            format_control = self.format_button_open
+            current_format = self.format
+            urgent = False
+        else:
+            format_control = self.format_button_closed
+            current_format = self.format_closed
+            urgent = mod_urgent or self.urgent
 
+        button = {"full_text": format_control, "index": "button"}
+        response = {
+            "cached_until": cached_until,
+            "full_text": self.py3.safe_format(
+                current_format,
+                {
+                    "output": self.py3.composite_create(output),
+                    "button": self.py3.composite_create(button),
+                },
+            ),
+        }
         if urgent:
             response["urgent"] = urgent
+            self.urgent = False
         return response
 
     def on_click(self, event):
         """
         Switch the displayed module or pass the event on to the active module
         """
-        if not self.items:
-            return
+        button = event["button"]
+        index = event["index"]
 
-        # if click_mode is button then we only action clicks that are
-        # directly on the group not its contents.
+        # if click_mode is button, prevent the contents from changing when
+        # if the events are not registered on the button index. this allow
+        # the users to interact with the modules via scrolling or clicking
+        # without group getting in the way of the contents.
         if self.click_mode == "button":
-            if not self.py3.is_my_event(event) or event.get("index") != "button":
+            if not self.py3.is_my_event(event) or index != "button":
                 return
 
-        # reset cycle time
-        self._cycle_time = time() + self.cycle
-        if self.button_next and event["button"] == self.button_next:
-            self._change_active(1)
-        if self.button_prev and event["button"] == self.button_prev:
-            self._change_active(-1)
-        if self.button_toggle and event["button"] == self.button_toggle:
-            # we only toggle if button was used
-            if event.get("index") == "button":
-                self.urgent = False
+        self.cycle = self.cycle_timeout
+        self.cycle_time = time() + self.cycle
+
+        if button == self.button_next:
+            if self.open:
+                self._change_active(+1)
+        elif button == self.button_prev:
+            if self.open:
+                self._change_active(-1)
+        elif button == self.button_toggle:
+            if index == "button":
                 self.open = not self.open
 
 
